.. _magnetostatics:

************************************************************
Magnetostatics (`plasmapy.formulary.magnetostatics`)
************************************************************

.. currentmodule:: plasmapy.formulary.magnetostatics

.. automodapi:: plasmapy.formulary.magnetostatics

Examples
========

.. nbgallery::
    :caption: Examples

    /notebooks/formulary/magnetostatics
